pub struct ArenaLeague {
pub id: Uuid,
pub name: I18nString,
pub min_rating: i64,
pub max_rating: i64,
}Fields
id: Uuidname: I18nStringmin_rating: i64max_rating: i64Trait Implementations
Sourceimpl Clone for ArenaLeague
impl Clone for ArenaLeague
Sourcefn clone(&self) -> ArenaLeague
fn clone(&self) -> ArenaLeague
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaLeague
impl Debug for ArenaLeague
Sourceimpl<'de> Deserialize<'de> for ArenaLeague
impl<'de> Deserialize<'de> for ArenaLeague
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaLeague
impl JsonSchema for ArenaLeague
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ArenaLeague
impl Serialize for ArenaLeague
Sourceimpl Tsify for ArenaLeague
impl Tsify for ArenaLeague
const DECL: &'static str = "export interface ArenaLeague {\n id: Uuid;\n name: I18nString;\n min_rating: number;\n max_rating: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>