pub struct ArenaSettings {Show 18 fields
pub base_rating: u64,
pub win_rating_increase_script: String,
pub lose_rating_increase_script: String,
pub matches_history_size: u64,
pub leaderboard_size: u64,
pub arena_tickets_currency_id: CurrencyId,
pub matchmaking_character_rating_delta: u64,
pub pvp_cooldown_secs: u64,
pub win_stars_increase: i64,
pub lose_stars_decrease: i64,
pub stars_reward_threshold: i64,
pub stars_reward_bundle_id: BundleId,
pub arena_ticket_buy_currency_id: CurrencyId,
pub arena_ticket_price: CurrencyUnit,
pub arena_matches_ttl_days: u64,
pub rematch_max_rating_increase: i64,
pub rematch_max_rating_decrease: i64,
pub daily_stars_claims_limit: i64,
}Fields
base_rating: u64win_rating_increase_script: Stringlose_rating_increase_script: Stringmatches_history_size: u64leaderboard_size: u64arena_tickets_currency_id: CurrencyIdmatchmaking_character_rating_delta: u64pvp_cooldown_secs: u64win_stars_increase: i64lose_stars_decrease: i64stars_reward_threshold: i64stars_reward_bundle_id: BundleIdarena_ticket_buy_currency_id: CurrencyIdarena_ticket_price: CurrencyUnitarena_matches_ttl_days: u64rematch_max_rating_increase: i64rematch_max_rating_decrease: i64daily_stars_claims_limit: i64Trait Implementations
Sourceimpl Clone for ArenaSettings
impl Clone for ArenaSettings
Sourcefn clone(&self) -> ArenaSettings
fn clone(&self) -> ArenaSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaSettings
impl Debug for ArenaSettings
Sourceimpl<'de> Deserialize<'de> for ArenaSettings
impl<'de> Deserialize<'de> for ArenaSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaSettings
impl JsonSchema for ArenaSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ArenaSettings
impl Serialize for ArenaSettings
Sourceimpl Tsify for ArenaSettings
impl Tsify for ArenaSettings
const DECL: &'static str = "export interface ArenaSettings {\n base_rating: number;\n win_rating_increase_script: string;\n lose_rating_increase_script: string;\n matches_history_size: number;\n leaderboard_size: number;\n arena_tickets_currency_id: CurrencyId;\n matchmaking_character_rating_delta: number;\n pvp_cooldown_secs: number;\n win_stars_increase: number;\n lose_stars_decrease: number;\n stars_reward_threshold: number;\n stars_reward_bundle_id: BundleId;\n arena_ticket_buy_currency_id: CurrencyId;\n arena_ticket_price: CurrencyUnit;\n arena_matches_ttl_days: number;\n rematch_max_rating_increase: number;\n rematch_max_rating_decrease: number;\n daily_stars_claims_limit: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>