pub struct FightSettings {
pub start_fight_delay_ticks_default: u64,
pub prepare_fight_win_delay_ticks_default: u64,
pub prepare_fight_lose_delay_ticks_default: u64,
pub end_fight_delay_ticks_default: u64,
pub player_start_position: Coordinates,
pub party_start_position: Coordinates,
pub power_adjust_script: String,
pub pvp_enemy_start_position: Coordinates,
}Fields
start_fight_delay_ticks_default: u64prepare_fight_win_delay_ticks_default: u64prepare_fight_lose_delay_ticks_default: u64end_fight_delay_ticks_default: u64player_start_position: Coordinatesparty_start_position: Coordinatespower_adjust_script: Stringpvp_enemy_start_position: CoordinatesTrait Implementations
Sourceimpl Clone for FightSettings
impl Clone for FightSettings
Sourcefn clone(&self) -> FightSettings
fn clone(&self) -> FightSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FightSettings
impl Debug for FightSettings
Sourceimpl<'de> Deserialize<'de> for FightSettings
impl<'de> Deserialize<'de> for FightSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FightSettings
impl JsonSchema for FightSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for FightSettings
impl Serialize for FightSettings
Sourceimpl Tsify for FightSettings
impl Tsify for FightSettings
const DECL: &'static str = "export interface FightSettings {\n start_fight_delay_ticks_default: number;\n prepare_fight_win_delay_ticks_default: number;\n prepare_fight_lose_delay_ticks_default: number;\n end_fight_delay_ticks_default: number;\n player_start_position: Coordinates;\n party_start_position: Coordinates;\n power_adjust_script: string;\n pvp_enemy_start_position: Coordinates;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>